@@ -1,10 +1,25 @@
-from requests_futures.sessions import FuturesSession
-import urllib
-import requests
-import urlparse
 import json
 import copy
 
+import requests
+
+
+try:
+    from requests_futures.sessions import FuturesSession
+    requests_futures_available = True
+except ImportError:
+    requests_futures_available = False
+
+
+try:
+    import urllib.parse as urlparse
+except ImportError:
+    import urlparse
+
+
+class RequestsFutureNotAvailable(Exception):
+    message = "Please install request_sessions before proceeding."
+
 
 class Resource(object):
 
@@ -25,8 +40,10 @@ class Resource(object):
         if kwargs.get('session'):
             self._session = kwargs['session']
             del kwargs['session']
-        elif kwargs.has_key('async'):
+        elif 'async' in kwargs:
             if kwargs['async']:
+                if not requests_futures_available:
+                    raise RequestsFutureNotAvailable()
                 self._session = FuturesSession()
             else:
                 self._session = requests.Session()
@@ -85,30 +102,15 @@ class Resource(object):
                 opts['params'] = params
 
         # make the request
-        future = getattr(
-            self._session,
-            method)(
-                self._make_url(
-                    path),
-                **opts)
+        future = getattr(self._session, method)(self._make_url(path), **opts)
         return future
 
-    def session(self, **kwargs):
-        """Get current user's authentication and authorization status."""
-        return self.get(self._reset_path('_session'), **kwargs)
-
-    def login(self, username, password, **kwargs):
-        """Authenticate the connection via cookie."""
-        # set headers, body explicitly
-        headers = {
-            "Content-Type": "application/x-www-form-urlencoded"
-        }
-        data = "name=%s&password=%s" % (username, password)
-        return self.post(self._reset_path('_session'), headers=headers, data=data, **kwargs)
-
-    def logout(self, **kwargs):
-        """De-authenticate the connection's cookie."""
-        return self.delete(self._reset_path('_session'), **kwargs)
+    def head(self, path='', **kwargs):
+        """
+        Make a HEAD request against the object's URI joined
+        with `path`. `kwargs` are passed directly to Requests.
+        """
+        return self._make_request('head', path, **kwargs)
 
     def get(self, path='', **kwargs):
         """
